#!/usr/bin/env python
# -*- coding: utf-8 -*-

import click
import json
import requests

@click.command(
    context_settings=dict(help_option_names=["-h", "--help"]),
    help=(
        "Post slack message masquerading as a fictitious user"
    ),
)
@click.argument(
    "channel", type=str, metavar="SLACK_CHANNEL_URL", nargs=1
)
@click.argument("username", type=str, metavar="USER", nargs=1)
@click.argument("message", type=str, metavar="MESSAGE", nargs=1)
@click.argument("emoji", type=str, metavar="EMOJI", nargs=1)
@click.version_option(__VERSION__)
def slackerade_cli(channel, username, message, emoji):
    payload = {"urls": (channel, ),
        "username": username,
        "text": message,
        "icon_emoji": emoji
    requests.post(channel, {"payload": json.dumps(payload)}, verify=False)

if __name__ == "__main__":
    slackerade_cli()



#!/usr/bin/env python

# Copyright (c) 2020 Fabrice Laporte - kray.me
# The MIT License http://www.opensource.org/licenses/mit-license.php

import os
import time

from setuptools import setup

VERSION = '0.0.2-dev'
DIRPATH = os.path.dirname(__file__)

setup(name='memedict',
    version=VERSION if not VERSION.endswith('dev') else '%s%s' % (VERSION, int(time.time())),
    description='Masquerade yourself as a fictitious user on slack',
    long_description=open(os.path.join(DIRPATH, 'README.rst')).read(),
    author='Fabrice Laporte',
    author_email='kraymer@gmail.com',
    url='https://github.com/KraYmer/slackerade',
    license='MIT',
    platforms='ALL',

    packages=[
      'slackerade',
    ],
      entry_points={
          'console_scripts': [
              'slackerade = slackerade:slackerade_cli',
          ],
      },
    install_requires=open(os.path.join(DIRPATH, 'requirements.txt')).read().split('\n'),
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Topic :: Communications :: Chat',
    ],
    keywords='Masquerade yourself as a fictitious user on slack',
    )